### ------------------------------------------------------------------
### | Copyright Unpublished, Atria Software, Inc.  All Rights        |
### | Reserved.  This software contains proprietary and confidential |
### | information of Atria and its suppliers.  Use, disclosure or    |
### | reproduction is prohibited without the prior express written   |
### | consent of Atria.                                              |
### ------------------------------------------------------------------
###

# Verify that the snapshot view's "view.dat" file is missing and
# regenerate it / associate it with the specified snapshot view pname.

if (-d "C:/") {
    $NT=1;
    $ATRIA_PERL='C:/atria/bin/ccperl';
    $pname_sep_str="\\";
    $dat_fname="view.dat";
    $stg_fname="view.stg";
} else {
    $NT=0;
    $ATRIA_PERL='/usr/atria/bin/Perl';
    $pname_sep_str="/";
    $dat_fname=".view.dat";
    $stg_fname=".view.stg";
}

$usage = "usage: $ATRIA_PERL regen_view_dot_dat.pl [-tag snapshot-view-tag] snapshot-view-pname\n";

$| = 1; # unbuffered output
$ct='cleartool';

#
# Parse cmd line
#

if ($ARGV[0] eq "-tag") {
    shift(@ARGV);
    die($usage) unless $ARGV[0];
    $snapshot_view_tag = $ARGV[0];
    shift(@ARGV);
}

die($usage) unless $ARGV[0];
$snapshot_view_pname = $ARGV[0];

$view_dat_pn = $snapshot_view_pname . $pname_sep_str . $dat_fname;

#
# Do some sanity checks on the snapshot view stg
#

if (! -d $snapshot_view_pname) {
    print "Invalid snapshot view pathname \"$snapshot_view_pname\": Not a directory.\n";
    die($usage);
}

if (-f $view_dat_pn) {
    print "\"$view_dat_pn\" already exists.\n";
    die($usage);
}

#
# Get the view info from rgy and check it.
#

if ($snapshot_view_tag) {
    @lsview_data = `$ct lsview -l $snapshot_view_tag`;
} else {
    # No view tag; view-stg is required to be in the default location
    $view_stg_dir = $snapshot_view_pname . $pname_sep_str . $stg_fname;
    if (! -d $view_stg_dir) {
	print "The snapshot view's view stg dir is not in the default location.  Use the \"-tag\" option.\n";
	die($usage);
    }

    $dot_view_pn = $view_stg_dir . $pname_sep_str . ".view";
    open(DOT_VIEW, $dot_view_pn) || die("Can't open \"$dot_view_pn\"");
    @dot_view_data = <DOT_VIEW>;
    close(DOT_VIEW);

    $dot_view_uuid = @dot_view_data[1];
    @lsview_data = `$ct lsview -l -uuid $dot_view_uuid`;
}
chomp(@lsview_data);
($rgy_view_uuid) = grep(/^View uuid:/, @lsview_data);
$rgy_view_uuid =~ s/^View uuid: //;
$rgy_view_uuid =~ s/[:\.]//g;  # strip punctuation in uuid
print "rgy_view_uuid: \"$rgy_view_uuid\".\n";

if (! $rgy_view_uuid) {
    if ($snapshot_view_tag) {
	print "Unable to get rgy info for view \"$snapshot_view_tag\".\n";
    } else {
	print "Unable to get rgy info for view \"$view_uuid\".\n";
    }
    die($usage);
}
if (grep(/^View attributes: snapshot/, @lsview_data) != 1) {
    if ($snapshot_view_tag) {
	print "\"$snapshot_view_tag\"";
    } else {
	print "\"$rgy_view_uuid\"";
    }
    print " is not a snapshot view: its view registry entry doesn't have a \"snapshot\" attribute.\n";
    die($usage);
}

#
# Everything looks OK, generate the view.dat file.
#

print "creating \"$view_dat_pn\".\n";

binmode(VIEW_DAT);
open(VIEW_DAT, ">$view_dat_pn") || die("Can't create $view_dat_pn");
print VIEW_DAT "ws_oid:00000000000000000000000000000000 view_uuid:$rgy_view_uuid";
close(VIEW_DAT);
if ($NT) {
    system("attrib +h +r $view_dat_pn");
} else {
    chmod(0444, $view_dat_pn);
}
exit(0);
